==> Acme-Postmodern-Perl-0.09.tar.gz: Acme-Postmodern-Perl-0.09/lib/Acme/Postmodern/Perl.pm <==
package Acme::Postmodern::Perl 0.09;

use warnings;
use strict;

=head1 NAME

Acme::Postmodern::Perl - Postmodern Perl solves all problems

=head1 VERSION

Version 0.09

=head1 SYNOPSIS

    use Acme::Postmodern::Perl;

This module requires the next upcoming stable perl version.

=head1 HOW TO INSTALL (or: how to give it a try, at least)

L<CPAN>.pm and its friends (like L<App::cpanminus>) don't play nicely with the
C<package NAMESPACE VERSION> syntax (which was introduced in perl5 v12). So if
you want to get the latest version of this distribution, you have to download it
directly from your nearby CPAN mirror.

=cut

use 5.022;

-1;
__END__

=head1 AUTHOR

Frank Wiegand, C<< <frank.wiegand at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-acme-postmodern-perl at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-Postmodern-Perl>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Acme::Postmodern::Perl

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-Postmodern-Perl>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Acme-Postmodern-Perl>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Acme-Postmodern-Perl>

=item * Search CPAN

L<http://search.cpan.org/dist/Acme-Postmodern-Perl/>

=back

=head1 SEE ALSO

L<Acme::Very::Modern::Perl>.

=head1 COPYRIGHT & LICENSE

Copyright 2009, 2010, 2011, 2012, 2013, 2014 Frank Wiegand L<mailto:fwie@cpan.org>.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

==> Acme-Postmodern-Perl-0.10.tar.gz: Acme-Postmodern-Perl-0.10/lib/Acme/Postmodern/Perl.pm <==
package Acme::Postmodern::Perl 0.10;

use warnings;
use strict;

=head1 NAME

Acme::Postmodern::Perl - Postmodern Perl solves all problems

=head1 VERSION

Version 0.10

=head1 SYNOPSIS

    use Acme::Postmodern::Perl;

This module requires the next upcoming stable perl version.

=head1 HOW TO INSTALL (or: how to give it a try, at least)

L<CPAN>.pm and its friends (like L<App::cpanminus>) don't play nicely with the
C<package NAMESPACE VERSION> syntax (which was introduced in perl5 v12). So if
you want to get the latest version of this distribution, you have to download it
directly from your nearby CPAN mirror.

=cut

use 5.032;

-1;
__END__

=head1 AUTHOR

Frank Wiegand, C<< <fwie at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-acme-postmodern-perl at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-Postmodern-Perl>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Acme::Postmodern::Perl

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-Postmodern-Perl>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Acme-Postmodern-Perl>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Acme-Postmodern-Perl>

=item * Search CPAN

L<http://search.cpan.org/dist/Acme-Postmodern-Perl/>

=back

=head1 SEE ALSO

L<Acme::Very::Modern::Perl>.

=head1 COPYRIGHT & LICENSE

Copyright 2009, 2010, 2011, 2012, 2013, 2014, 2020 Frank Wiegand L<mailto:fwie@cpan.org>.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut
